@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 5.19 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 6.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2019, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +22,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcs.h,v 5.19 2018/07/26 15:37:04 mcalabre Exp $
+  $Id: wcs.h,v 6.3 2019/07/12 07:33:39 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 5.19 - C routines that implement the FITS World Coordinate System
+* WCSLIB 6.3 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -56,6 +56,11 @@
 =
 =   "Representing the 'Butterfly' Projection in FITS -- Projection Code XPH",
 =   Calabretta, M.R., & Lowe, S.R. 2013, PASA, 30, e050 (WCS Paper VI)
+=
+=   "Representations of time coordinates in FITS -
+=    Time and relative dimension in space",
+=   Rots, A.H., Bunclark, P.S., Calabretta, M.R., Allen, S.L.,
+=   Manchester, R.N., & Thompson, W.T. 2015, A&A, 574, A36 (WCS Paper VII)
 *
 * These routines are based on the wcsprm struct which contains all information
 * needed for the computations.  The struct contains some members that must be
@@ -1054,13 +1059,13 @@
 *     alternate specifications of the linear transformation matrix, those
 *     associated with the CDi_ja keywords, and ...
 *   double *crota
-*     (Given) ... those associated with the CROTAia keywords.  Although these
+*     (Given) ... those associated with the CROTAi keywords.  Although these
 *     may not formally co-exist with PCi_ja, the approach taken here is simply
 *     to ignore them if given in conjunction with PCi_ja.
 *
 *   int altlin
 *     (Given) altlin is a bit flag that denotes which of the PCi_ja, CDi_ja
-*     and CROTAia keywords are present in the header:
+*     and CROTAi keywords are present in the header:
 *
 *     - Bit 0: PCi_ja is present.
 *
@@ -1070,27 +1075,27 @@
 *       equivalent to the product CDi_ja = CDELTia * PCi_ja, but the
 *       defaults differ from that of the PCi_ja matrix.  If one or more
 *       CDi_ja keywords are present then all unspecified CDi_ja default to
-*       zero.  If no CDi_ja (or CROTAia) keywords are present, then the
+*       zero.  If no CDi_ja (or CROTAi) keywords are present, then the
 *       header is assumed to be in PCi_ja form whether or not any PCi_ja
 *       keywords are present since this results in an interpretation of
 *       CDELTia consistent with the original FITS specification.
 *
 *       While CDi_ja may not formally co-exist with PCi_ja, it may co-exist
-*       with CDELTia and CROTAia which are to be ignored.
+*       with CDELTia and CROTAi which are to be ignored.
 *
-*     - Bit 2: CROTAia is present.
+*     - Bit 2: CROTAi is present.
 *
-*       In the AIPS convention, CROTAia may only be
+*       In the AIPS convention, CROTAi may only be
 *       associated with the latitude axis of a celestial axis pair.  It
 *       specifies a rotation in the image plane that is applied AFTER the
-*       CDELTia; any other CROTAia keywords are ignored.
+*       CDELTia; any other CROTAi keywords are ignored.
 *
-*       CROTAia may not formally co-exist with PCi_ja.
+*       CROTAi may not formally co-exist with PCi_ja.
 *
-*       CROTAia and CDELTia may formally co-exist with CDi_ja but if so are to
+*       CROTAi and CDELTia may formally co-exist with CDi_ja but if so are to
 *       be ignored.
 *
-*     CDi_ja and CROTAia keywords, if found, are to be stored in the
+*     CDi_ja and CROTAi keywords, if found, are to be stored in the
 *     wcsprm::cd and wcsprm::crota arrays which are dimensioned similarly to
 *     wcsprm::pc and wcsprm::cdelt.  FITS
 *     header parsers should use the following procedure:
@@ -1099,7 +1104,7 @@
 *
 *     - Whenever a CDi_ja  keyword is encountered: altlin |= 2;
 *
-*     - Whenever a CROTAia keyword is encountered: altlin |= 4;
+*     - Whenever a CROTAi keyword is encountered: altlin |= 4;
 *
 *     If none of these bits are set the PCi_ja representation results, i.e.
 *     wcsprm::pc and wcsprm::cdelt will be used as given.
@@ -1109,7 +1114,7 @@
 *     lower-level WCSLIB routines.  In particular, wcsset() resets
 *     wcsprm::cdelt to unity if CDi_ja is present (and no PCi_ja).
 *
-*     If CROTAia are present but none is associated with the latitude axis
+*     If CROTAi are present but none is associated with the latitude axis
 *     (and no PCi_ja or CDi_ja), then wcsset() reverts to a unity PCi_ja
 *     matrix.
 *
@@ -1176,21 +1181,242 @@
 *     It is not necessary to reset the wcsprm struct (via wcsset()) when
 *     wcsprm::csyer is changed.
 *
-*   char dateavg[72]
-*     (Given, auxiliary) The date of a representative mid-point of the
-*     observation in ISO format, yyyy-mm-ddThh:mm:ss.
+*   double *czphs
+*     (Given, auxiliary) Address of the first element of an array of double
+*     recording the time at the zero point of a phase axis, CZPHSia.
 *
 *     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::dateavg is changed.
+*     wcsprm::czphs is changed.
+*
+*   double *cperi
+*     (Given, auxiliary) Address of the first element of an array of double
+*     recording the period of a phase axis, CPERIia.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::cperi is changed.
+*
+*   char wcsname[72]
+*     (Given, auxiliary) The name given to the coordinate representation,
+*     WCSNAMEa.  This variable accomodates the longest allowed string-valued
+*     FITS keyword, being limited to 68 characters, plus the null-terminating
+*     character.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::wcsname is changed.
+*
+*   char timesys[72]
+*     (Given, auxiliary) TIMESYS keyvalue, being the time scale (UTC, TAI,
+*     etc.) in which all other time-related auxiliary header values are
+*     recorded.  Also defines the time scale for an image axis with CTYPEia
+*     set to 'TIME'.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timesys is changed.
+*
+*   char trefpos[72]
+*     (Given, auxiliary) TREFPOS keyvalue, being the location in space where
+*     the recorded time is valid.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::trefpos is changed.
+*
+*   char trefdir[72]
+*     (Given, auxiliary) TREFDIR keyvalue, being the reference direction used
+*     in calculating a pathlength delay.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::trefdir is changed.
+*
+*   char plephem[72]
+*     (Given, auxiliary) PLEPHEM keyvalue, being the Solar System ephemeris
+*     used for calculating a pathlength delay.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::plephem is changed.
+*
+*   char timeunit[72]
+*     (Given, auxiliary) TIMEUNIT keyvalue, being the time units in which
+*     the following header values are expressed: TSTART, TSTOP, TIMEOFFS,
+*     TIMSYER, TIMRDER, TIMEDEL.  It also provides the default value for
+*     CUNITia for time axes.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timeunit is changed.
+*
+*   char dateref[72]
+*     (Given, auxiliary) DATEREF keyvalue, being the date of a reference epoch
+*     relative to which other time measurements refer.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::dateref is changed.
+*
+*   double mjdref[2]
+*     (Given, auxiliary) MJDREF keyvalue, equivalent to DATEREF expressed as
+*     a Modified Julian Date (MJD = JD - 2400000.5).  The value is given as
+*     the sum of the two-element vector, allowing increased precision.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::mjdref is changed.
+*
+*   double timeoffs
+*     (Given, auxiliary) TIMEOFFS keyvalue, being a time offset, which may be
+*     used, for example, to provide a uniform clock correction for times
+*     referenced to DATEREF.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timeoffs is changed.
 *
 *   char dateobs[72]
-*     (Given, auxiliary) The date of the start of the observation unless
-*     otherwise explained in the comment field of the DATE-OBS keyword, in
+*     (Given, auxiliary) DATE-OBS keyvalue, being the date at the start of the
+*     observation unless otherwise explained in the DATE-OBS keycomment, in
 *     ISO format, yyyy-mm-ddThh:mm:ss.
 *
 *     It is not necessary to reset the wcsprm struct (via wcsset()) when
 *     wcsprm::dateobs is changed.
 *
+*   char datebeg[72]
+*     (Given, auxiliary) DATE-BEG keyvalue, being the date at the start of the
+*     observation in ISO format, yyyy-mm-ddThh:mm:ss.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::datebeg is changed.
+*
+*   char dateavg[72]
+*     (Given, auxiliary) DATE-AVG keyvalue, being the date at a representative
+*     mid-point of the observation in ISO format, yyyy-mm-ddThh:mm:ss.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::dateavg is changed.
+*
+*   char dateend[72]
+*     (Given, auxiliary) DATE-END keyvalue, baing the date at the end of the
+*     observation in ISO format, yyyy-mm-ddThh:mm:ss.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::dateend is changed.
+*
+*   double mjdobs
+*     (Given, auxiliary) MJD-OBS keyvalue, equivalent to DATE-OBS expressed
+*     as a Modified Julian Date (MJD = JD - 2400000.5).
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::mjdobs is changed.
+*
+*   double mjdbeg
+*     (Given, auxiliary) MJD-BEG keyvalue, equivalent to DATE-BEG expressed
+*     as a Modified Julian Date (MJD = JD - 2400000.5).
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::mjdbeg is changed.
+*
+*   double mjdavg
+*     (Given, auxiliary) MJD-AVG keyvalue, equivalent to DATE-AVG expressed
+*     as a Modified Julian Date (MJD = JD - 2400000.5).
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::mjdavg is changed.
+*
+*   double mjdend
+*     (Given, auxiliary) MJD-END keyvalue, equivalent to DATE-END expressed
+*     as a Modified Julian Date (MJD = JD - 2400000.5).
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::mjdend is changed.
+*
+*   double jepoch
+*     (Given, auxiliary) JEPOCH keyvalue, equivalent to DATE-OBS expressed
+*     as a Julian epoch.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::jepoch is changed.
+*
+*   double bepoch
+*     (Given, auxiliary) BEPOCH keyvalue, equivalent to DATE-OBS expressed
+*     as a Besselian epoch
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::bepoch is changed.
+*
+*   double tstart
+*     (Given, auxiliary) TSTART keyvalue, equivalent to DATE-BEG expressed
+*     as a time in units of TIMEUNIT relative to DATEREF+TIMEOFFS.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::tstart is changed.
+*
+*   double tstop
+*     (Given, auxiliary) TSTOP keyvalue, equivalent to DATE-END expressed
+*     as a time in units of TIMEUNIT relative to DATEREF+TIMEOFFS.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::tstop is changed.
+*
+*   double xposure
+*     (Given, auxiliary) XPOSURE keyvalue, being the effective exposure time
+*     in units of TIMEUNIT.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::xposure is changed.
+*
+*   double telapse
+*     (Given, auxiliary) TELAPSE keyvalue, equivalent to the elapsed time
+*     between DATE-BEG and DATE-END, in units of TIMEUNIT.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::telapse is changed.
+*
+*   double timsyer
+*     (Given, auxiliary) TIMSYER keyvalue, being the absolute error of the
+*     time values, in units of TIMEUNIT.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timsyer is changed.
+*
+*   double timrder
+*     (Given, auxiliary) TIMRDER keyvalue, being the accuracy of time stamps
+*     relative to each other, in units of TIMEUNIT.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timrder is changed.
+*
+*   double timedel
+*     (Given, auxiliary) TIMEDEL keyvalue, being the resolution of the time
+*     stamps.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timedel is changed.
+*
+*   double timepixr
+*     (Given, auxiliary) TIMEPIXR keyvalue, being the relative position of the
+*     time stamps in binned time intervals, a value between 0.0 and 1.0.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::timepixr is changed.
+*
+*   double obsgeo[6]
+*     (Given, auxiliary) Location of the observer in a standard terrestrial
+*     reference frame.  The first three give ITRS Cartesian coordinates
+*     OBSGEO-X [m],   OBSGEO-Y [m],   OBSGEO-Z [m], and the second three give
+*     OBSGEO-L [deg], OBSGEO-B [deg], OBSGEO-H [m], which are related through
+*     a standard transformation.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::obsgeo is changed.
+*
+*   char obsorbit[72]
+*     (Given, auxiliary) OBSORBIT keyvalue, being the URI, URL, or name of an
+*     orbit ephemeris file giving spacecraft coordinates relating to TREFPOS.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::obsorbit is changed.
+*
+*   char radesys[72]
+*     (Given, auxiliary) The equatorial or ecliptic coordinate system type,
+*     RADESYSa.
+*
+*     It is not necessary to reset the wcsprm struct (via wcsset()) when
+*     wcsprm::radesys is changed.
+*
 *   double equinox
 *     (Given, auxiliary) The equinox associated with dynamical equatorial or
 *     ecliptic coordinate systems, EQUINOXa (or EPOCH in older headers).  Not
@@ -1199,34 +1425,6 @@
 *     It is not necessary to reset the wcsprm struct (via wcsset()) when
 *     wcsprm::equinox is changed.
 *
-*   double mjdavg
-*     (Given, auxiliary) Modified Julian Date (MJD = JD - 2400000.5), MJD-AVG,
-*     corresponding to DATE-AVG.
-*
-*     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::mjdavg is changed.
-*
-*   double mjdobs
-*     (Given, auxiliary) Modified Julian Date (MJD = JD - 2400000.5), MJD-OBS,
-*     corresponding to DATE-OBS.
-*
-*     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::mjdobs is changed.
-*
-*   double obsgeo[3]
-*     (Given, auxiliary) Location of the observer in a standard terrestrial
-*     reference frame, OBSGEO-X, OBSGEO-Y, OBSGEO-Z [m].
-*
-*     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::obsgeo is changed.
-*
-*   char radesys[72]
-*     (Given, auxiliary) The equatorial or ecliptic coordinate system type,
-*     RADESYSa.
-*
-*     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::radesys is changed.
-*
 *   char specsys[72]
 *     (Given, auxiliary) Spectral reference frame (standard of rest),
 *     SPECSYSa.
@@ -1270,15 +1468,6 @@
 *     It is not necessary to reset the wcsprm struct (via wcsset()) when
 *     wcsprm::velangl is changed.
 *
-*   char wcsname[72]
-*     (Given, auxiliary) The name given to the coordinate representation,
-*     WCSNAMEa.  This variable accomodates the longest allowed string-valued
-*     FITS keyword, being limited to 68 characters, plus the null-terminating
-*     character.
-*
-*     It is not necessary to reset the wcsprm struct (via wcsset()) when
-*     wcsprm::wcsname is changed.
-*
 *   int ntab
 *     (Given) See wcsprm::tab.
 *
@@ -1365,9 +1554,6 @@
 *     CTYPEia in "4-3" form with unrecognized algorithm code will have its
 *     type set to -1 and generate an error.
 *
-*   void *padding
-*     (An unused variable inserted for alignment purposes only.)
-*
 *   struct linprm lin
 *     (Returned) Linear transformation parameters (usage is described in the
 *     prologue to lin.h).
@@ -1384,8 +1570,6 @@
 *     (Returned) If enabled, when an error status is returned, this struct
 *     contains detailed information about the error, see wcserr_enable().
 *
-*   void *m_padding
-*     (For internal use only.)
 *   int m_flag
 *     (For internal use only.)
 *   int m_naxis
@@ -1418,6 +1602,10 @@
 *     (For internal use only.)
 *   double *m_csyer
 *     (For internal use only.)
+*   double *m_czphs
+*     (For internal use only.)
+*   double *m_cperi
+*     (For internal use only.)
 *   struct tabprm *m_tab
 *     (For internal use only.)
 *   struct wtbarr *m_wtb
@@ -1459,57 +1647,6 @@
 *     (Given) Parameter value.
 *
 *
-* wtbarr struct - Extraction of coordinate lookup tables from BINTABLE
-* --------------------------------------------------------------------
-* Function wcstab(), which is invoked automatically by wcspih(), sets up an
-* array of wtbarr structs to assist in extracting coordinate lookup tables
-* from a binary table extension (BINTABLE) and copying them into the tabprm
-* structs stored in wcsprm.  Refer to the usage notes for wcspih() and
-* wcstab() in wcshdr.h, and also the prologue to tab.h.
-*
-* For C++ usage, because of a name space conflict with the wtbarr typedef
-* defined in CFITSIO header fitsio.h, the wtbarr struct is renamed to wtbarr_s
-* by preprocessor macro substitution with scope limited to wcs.h itself.
-*
-*   int i
-*     (Given) Image axis number.
-*
-*   int m
-*     (Given) wcstab array axis number for index vectors.
-*
-*   int kind
-*     (Given) Character identifying the wcstab array type:
-*       - c: coordinate array,
-*       - i: index vector.
-*
-*   char extnam[72]
-*     (Given) EXTNAME identifying the binary table extension.
-*
-*   int extver
-*     (Given) EXTVER identifying the binary table extension.
-*
-*   int extlev
-*     (Given) EXTLEV identifying the binary table extension.
-*
-*   char ttype[72]
-*     (Given) TTYPEn identifying the column of the binary table that contains
-*     the wcstab array.
-*
-*   long row
-*     (Given) Table row number.
-*
-*   int ndim
-*     (Given) Expected dimensionality of the wcstab array.
-*
-*   int *dimlen
-*     (Given) Address of the first element of an array of int of length ndim
-*     into which the wcstab array axis lengths are to be written.
-*
-*   double **arrayp
-*     (Given) Pointer to an array of double which is to be allocated by the
-*     user and into which the wcstab array is to be written.
-*
-*
 * Global variable: const char *wcs_errmsg[] - Status return messages
 * ------------------------------------------------------------------
 * Error messages to match the status value returned from each function.
@@ -1525,6 +1662,7 @@
 
 #ifdef __cplusplus
 extern "C" {
+#define wtbarr wtbarr_s		/* See prologue of wtbarr.h.                */
 #endif
 
 #define WCSSUB_LONGITUDE 0x1001
@@ -1588,27 +1726,6 @@ struct pscard {
 /* Size of the pscard struct in int units, used by the Fortran wrappers. */
 #define PSLEN (sizeof(struct pscard)/sizeof(int))
 
-				/* For extracting wcstab arrays.  Matches   */
-				/* the wtbarr typedef defined in CFITSIO    */
-				/* header fitsio.h.                         */
-#ifdef __cplusplus
-#define wtbarr wtbarr_s		/* See prologue above.                      */
-#endif
-struct wtbarr {
-  int  i;			/* Image axis number.                       */
-  int  m;			/* Array axis number for index vectors.     */
-  int  kind;			/* wcstab array type.                       */
-  char extnam[72];		/* EXTNAME of binary table extension.       */
-  int  extver;			/* EXTVER  of binary table extension.       */
-  int  extlev;			/* EXTLEV  of binary table extension.       */
-  char ttype[72];		/* TTYPEn of column containing the array.   */
-  long row;			/* Table row number.                        */
-  int  ndim;			/* Expected wcstab array dimensionality.    */
-  int  *dimlen;			/* Where to write the array axis lengths.   */
-  double **arrayp;		/* Where to write the address of the array  */
-				/* allocated to store the wcstab array.     */
-};
-
 
 struct wcsprm {
   /* Initialization flag (see the prologue above).                          */
@@ -1643,35 +1760,52 @@ struct wcsprm {
   /* Alternative header keyvalues (see the prologue above).                 */
   /*------------------------------------------------------------------------*/
   double *cd;			/* CDi_ja linear transformation matrix.     */
-  double *crota;		/* CROTAia keyvalues for each coord axis.   */
+  double *crota;		/* CROTAi keyvalues for each coord axis.    */
   int    altlin;		/* Alternative representations              */
 				/*   Bit 0: PCi_ja  is present,             */
 				/*   Bit 1: CDi_ja  is present,             */
-				/*   Bit 2: CROTAia is present.             */
+				/*   Bit 2: CROTAi is present.              */
   int    velref;		/* AIPS velocity code, VELREF.              */
 
-  /* Auxiliary coordinate system information, not used by WCSLIB.           */
+  /* Auxiliary coordinate system information, not used by WCSLIB.  Refer to */
+  /* the prologue comments above for a brief explanation of these values.   */
   char   alt[4];
   int    colnum;
   int    *colax;
-
+				/* Auxiliary coordinate axis information.   */
   char   (*cname)[72];
   double *crder;
   double *csyer;
-  char   dateavg[72];
-  char   dateobs[72];
-  double equinox;
-  double mjdavg;
-  double mjdobs;
-  double obsgeo[3];
+  double *czphs;
+  double *cperi;
+
+  char   wcsname[72];
+				/* Time reference system and measurement.   */
+  char   timesys[72], trefpos[72], trefdir[72], plephem[72];
+  char   timeunit[72];
+  char   dateref[72];
+  double mjdref[2];
+  double timeoffs;
+				/* Data timestamps and durations.           */
+  char   dateobs[72], datebeg[72], dateavg[72], dateend[72];
+  double mjdobs, mjdbeg, mjdavg, mjdend;
+  double jepoch, bepoch;
+  double tstart, tstop;
+  double xposure, telapse;
+				/* Timing accuracy.                         */
+  double timsyer, timrder;
+  double timedel, timepixr;
+				/* Spatial & celestial reference frame.     */
+  double obsgeo[6];
+  char   obsorbit[72];
   char   radesys[72];
+  double equinox;
   char   specsys[72];
   char   ssysobs[72];
   double velosys;
   double zsource;
   char   ssyssrc[72];
   double velangl;
-  char   wcsname[72];
 
   /* Coordinate lookup tables (see the prologue above).                     */
   /*------------------------------------------------------------------------*/
@@ -1680,6 +1814,7 @@ struct wcsprm {
   struct tabprm *tab;		/* Tabular transformation parameters.       */
   struct wtbarr *wtb;		/* Array of wtbarr structs.                 */
 
+  /*------------------------------------------------------------------------*/
   /* Information derived from the FITS header keyvalues by wcsset().        */
   /*------------------------------------------------------------------------*/
   char   lngtyp[8], lattyp[8];	/* Celestial axis types, e.g. RA, DEC.      */
@@ -1687,19 +1822,21 @@ struct wcsprm {
 				/* indices (0-relative).                    */
   int    cubeface;		/* True if there is a CUBEFACE axis.        */
   int    *types;		/* Coordinate type codes for each axis.     */
-  void   *padding;		/* (Dummy inserted for alignment purposes.) */
 
-  struct linprm lin;		/* Linear    transformation parameters.     */
+  struct linprm lin;		/*    Linear transformation parameters.     */
   struct celprm cel;		/* Celestial transformation parameters.     */
-  struct spcprm spc;		/* Spectral  transformation parameters.     */
+  struct spcprm spc;		/*  Spectral transformation parameters.     */
+
+  /*------------------------------------------------------------------------*/
+  /*             THE REMAINDER OF THE WCSPRM STRUCT IS PRIVATE.             */
+  /*------------------------------------------------------------------------*/
 
   /* Error handling, if enabled.                                            */
   /*------------------------------------------------------------------------*/
   struct wcserr *err;
 
-  /* Private - the remainder are for memory management.                     */
+  /* Memory management.                                                     */
   /*------------------------------------------------------------------------*/
-  void   *m_padding;
   int    m_flag, m_naxis;
   double *m_crpix, *m_pc, *m_cdelt, *m_crval;
   char  (*m_cunit)[72], (*m_ctype)[72];
@@ -1708,7 +1845,7 @@ struct wcsprm {
   double *m_cd, *m_crota;
   int    *m_colax;
   char  (*m_cname)[72];
-  double *m_crder, *m_csyer;
+  double *m_crder, *m_csyer, *m_czphs, *m_cperi;
   struct tabprm *m_tab;
   struct wtbarr *m_wtb;
 };
